@@ -9,7 +9,7 @@ def get_all_urls(domain, num_of_api_urls=1, logging_level=logging.ERROR):
     logging.basicConfig(format='%(asctime)s: gau-python %(levelname)s: %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p',
                         level=logging_level)
 
-    urls = get_urls_wayback(domain)
+    urls = get_urls_otx(domain) + get_urls_commoncrawl(domain=domain, num_of_api_urls=num_of_api_urls) + get_urls_wayback(domain)
     urls.sort()
 
     return urls
